@@ -1,7 +1,7 @@
-"""A module for storing data schema."""
+"""A module for storing the data schema."""
 
 
-NAMED_SCHEMA = {
+NAMED_SCHEMA: dict = {
     "type": "array",
     "items": {
         "type": "object",
@@ -13,12 +13,14 @@ NAMED_SCHEMA = {
         "required": ["name"],
     },
 }
+"""Store the schema of the `series`, `dimensions` and `measures` data types."""
 
 
-RECORD_SCHEMA = {"type": "array", "items": {"type": "array"}}
+RECORD_SCHEMA: dict = {"type": "array", "items": {"type": "array"}}
+"""Store the schema of the `records` data type."""
 
 
-DATA_SCHEMA = {
+DATA_SCHEMA: dict = {
     "type": "object",
     "oneOf": [
         {
@@ -40,3 +42,4 @@ DATA_SCHEMA = {
         },
     ],
 }
+"""Store the schema of the data animation."""
